<?php
namespace plugins\smtp\controllers;

/**
 * Settings controller
 * @author Jérôme Brilland
 * @version 2.1
 * @copyright (c) 2019-2022, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class SettingsController extends \ActionController {

    protected function beforeFilter() {
        $authorization = \IoC::resolve( 'authorization' );
        $authorization->authorize( 'manage_settings' );
    }

    public function doIndex() {
        $settings = \IoC::resolve( 'settings' );
        $i18n = \IoC::resolve( 'i18n' );
        $this->title = $i18n->__( 'settings' );
        $this->host = $settings['smtp.host'];
        $this->enableAuthentication = $settings['smtp.enable_authentication'];
        $this->username = $settings['smtp.username'];
        $this->password = $settings['smtp.password'];
        $this->port = $settings['smtp.port'];
        $this->encryptionMode = $settings['smtp.encryption_mode'];
        $this->render( 'settingsform.html' );
    }

    public function doUpdate() {
        $configurationHandler = \IoC::resolve( 'databaseConfigurationHandler');
        $settings = new \Configuration( $configurationHandler );
        $settings['smtp.host'] = $this->request->getParameters()->getString( 'smtp_host' );
        $settings['smtp.enable_authentication'] = $this->request->getParameters()->getInt( 'smtp_enable_authentication' );
        $settings['smtp.username'] = $this->request->getParameters()->getString( 'smtp_username' );
        $settings['smtp.password'] = $this->request->getParameters()->getString( 'smtp_password' );
        $settings['smtp.port'] = $this->request->getParameters()->getInt( 'smtp_port' );
        $settings['smtp.encryption_mode'] = $this->request->getParameters()->getString( 'smtp_encryption_mode' );
        $configurationHandler->save();
        $this->flash['success'] = \IoC::resolve( 'i18n' )->__( 'settings_successfully_updated' );
        $this->redirect( BASE_URL . 'smtp/settings' );
    }
}
